@@ -1,8 +1,8 @@
 package WebService::MyAffiliates;
 
 use strict;
-use 5.008_005;
-our $VERSION = '0.07';
+use warnings;
+our $VERSION = '0.08';
 
 use Carp;
 use Mojo::UserAgent;
@@ -10,11 +10,11 @@ use Mojo::Util qw(b64_encode url_escape);
 use XML::Simple 'XMLin';
 
 use vars qw/$errstr/;
-sub errstr { $errstr }
+sub errstr { return $errstr }
 
-sub new {
+sub new {    ## no critic (ArgUnpacking)
     my $class = shift;
-    my %args  = @_ % 2 ? %{$_[0]} : @_;
+    my %args = @_ % 2 ? %{$_[0]} : @_;
 
     for (qw/user pass host/) {
         $args{$_} || croak "Param $_ is required.";
@@ -24,7 +24,7 @@ sub new {
     $args{host} = 'http://' . $args{host} unless $args{host} =~ m{^https?\://};
     $args{host} =~ s{/$}{};
 
-    $args{timeout}  ||= 30; # for ua timeout
+    $args{timeout} ||= 30;    # for ua timeout
 
     return bless \%args, $class;
 }
@@ -37,7 +37,7 @@ sub __ua {
     my $ua = Mojo::UserAgent->new;
     $ua->max_redirects(3);
     $ua->inactivity_timeout($self->{timeout});
-    $ua->proxy->detect; # env proxy
+    $ua->proxy->detect;    # env proxy
     $ua->max_connections(100);
     $self->{ua} = $ua;
 
@@ -45,12 +45,12 @@ sub __ua {
 }
 
 ## https://myaffiliates.atlassian.net/wiki/display/PUB/Feed+1%3A+Users+Feed
-sub get_users {
+sub get_users {            ## no critic (ArgUnpacking)
     my $self = shift;
     my %args = @_ % 2 ? %{$_[0]} : @_;
-    my $url = Mojo::URL->new('/feeds.php?FEED_ID=1');
+    my $url  = Mojo::URL->new('/feeds.php?FEED_ID=1');
     $url->query(\%args) if %args;
-    $self->request($url->to_string);
+    return $self->request($url->to_string);
 }
 
 sub get_user {
@@ -66,24 +66,24 @@ sub decode_token {
     my $self = shift;
     my @tokens = @_ or croak 'Must pass at least one token.';
 
-    $self->request('/feeds.php?FEED_ID=4&TOKENS=' . url_escape(join(',', @tokens)));
+    return $self->request('/feeds.php?FEED_ID=4&TOKENS=' . url_escape(join(',', @tokens)));
 }
 
 ## https://myaffiliates.atlassian.net/wiki/display/PUB/Feed+5%3A+Encode+Token
-sub encode_token {
+sub encode_token {    ## no critic (ArgUnpacking)
     my $self = shift;
     my %args = @_ % 2 ? %{$_[0]} : @_;
 
-    $args{USER_ID} or croak "USER_ID is required.";
+    $args{USER_ID}  or croak "USER_ID is required.";
     $args{SETUP_ID} or croak "SETUP_ID is required.";
 
     my $url = Mojo::URL->new('/feeds.php?FEED_ID=5');
     $url->query(\%args) if %args;
-    $self->request($url->to_string);
+    return $self->request($url->to_string);
 }
 
 ## https://myaffiliates.atlassian.net/wiki/display/PUB/Feed+6%3A+User+Transactions+Feed
-sub get_user_transactions {
+sub get_user_transactions {    ## no critic (ArgUnpacking)
     my $self = shift;
     my %args = @_ % 2 ? %{$_[0]} : @_;
 
@@ -91,7 +91,7 @@ sub get_user_transactions {
 
     my $url = Mojo::URL->new('/feeds.php?FEED_ID=6');
     $url->query(\%args) if %args;
-    $self->request($url->to_string);
+    return $self->request($url->to_string);
 }
 
 sub request {
@@ -99,19 +99,17 @@ sub request {
 
     $method ||= 'GET';
 
-    my $ua = $self->__ua;
-    my $header = {
-        Authorization => 'Basic ' . b64_encode($self->{user} . ':' . $self->{pass}, '')
-    };
-    my @extra = %params ? (form => \%params) : ();
-    my $tx = $ua->build_tx($method => $self->{host} . $url => $header => @extra);
+    my $ua     = $self->__ua;
+    my $header = {Authorization => 'Basic ' . b64_encode($self->{user} . ':' . $self->{pass}, '')};
+    my @extra  = %params ? (form => \%params) : ();
+    my $tx     = $ua->build_tx($method => $self->{host} . $url => $header => @extra);
 
     $tx = $ua->start($tx);
     # use Data::Dumper; print STDERR Dumper(\$tx);
     if ($tx->res->headers->content_type and $tx->res->headers->content_type =~ 'text/xml') {
         return XMLin($tx->res->body);
     }
-    if (! $tx->success) {
+    if (!$tx->success) {
         $errstr = $tx->error->{message};
         return;
     }
@@ -149,6 +147,7 @@ WebService::MyAffiliates - Interface to myaffiliates.com API
         host => 'admin.example.com'
     );
 
+    my $token; # initial it
     my $token_info = $aff->decode_token($token) or die $aff->errstr;
 
 =head1 DESCRIPTION
@@ -225,6 +224,12 @@ L<https://myaffiliates.atlassian.net/wiki/display/PUB/Feed+6%3A+User+Transaction
         'TO_DATE'   => '2012-01-31',
     );
 
+=head2 errstr
+
+=head2 get_affiliate_id_from_token
+
+=head2 request
+
 =head1 AUTHOR
 
 Binary.com E<lt>fayland@binary.comE<gt>
